"""config URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/3.2/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.contrib import admin
from django.urls import path, include
from django.views.generic import TemplateView
from django.conf.urls.static import static
from django.conf import settings
from django.http import HttpResponse

from rest_framework_simplejwt.views import (
    TokenObtainPairView,
    TokenRefreshView,
    TokenVerifyView,
)

# API documentation
from rest_framework import permissions
from drf_yasg.views import get_schema_view
from drf_yasg import openapi


api_patterns = [
    path('api/v1/', include('api.urls')),
    path('api/v1/api-auth/', include('rest_framework.urls')),
    path('api/v1/token/', TokenObtainPairView.as_view(), name='token_obtain_pair'),
    path('api/v1/token/refresh/', TokenRefreshView.as_view(), name='token_refresh'),
    path('api/v1/token/verify/', TokenVerifyView.as_view(), name='token_verify'),

    path('api/v1/ping/', lambda request: HttpResponse('pong'), name='ping_pong'),
]


# API docs schema
schema_view = get_schema_view(
    openapi.Info(
        title="Photo Log API",
        default_version="v1",
        description="Storing and retrieving photos for creating photo logs.",
    ),
    patterns=api_patterns,
    public=True,
    permission_classes=(permissions.AllowAny,),
)


urlpatterns = [
    path('api/admin/', admin.site.urls),
    path('api/v1/docs/', schema_view.with_ui('redoc', cache_timeout=0), name='schema-redoc'),
]

urlpatterns += api_patterns
urlpatterns += static(settings.STATIC_URL,document_root=settings.STATIC_ROOT)
